import Account from './account'
import Balance from './balance'
import Block from './block'
import Channel from './channel'
import Council from './council'
import Consul from './councilseat'
import ConsulStake from './councilstake'
import Era from './era'
import Event from './event'
import Proposal from './proposal'
import ProposalVote from './proposalVote'
import Member from './member'
import Category from './category'
import Thread from './thread'
import Post from './post'

Member.hasMany(Account)
Member.hasMany(Consul, { as: 'terms' })
Member.hasMany(ConsulStake, { as: 'votes' })
Member.hasMany(Category, { as: 'categories' })
Member.hasMany(Thread, { as: 'threads' })
Member.hasMany(Post, { as: 'posts' })
Member.hasMany(Proposal, { as: 'proposals' })

Account.belongsTo(Member)
Account.hasMany(Balance)
Account.hasMany(Block, { foreignKey: 'validatorId' })

Balance.belongsTo(Account)
Balance.belongsTo(Era)

Era.hasMany(Balance)
Era.hasMany(Block)

Block.belongsTo(Account, { as: 'validator' })
Block.belongsTo(Era)
Block.hasMany(Event)
Event.belongsTo(Block)

Council.hasMany(Consul)
Council.hasMany(Proposal)
Consul.belongsTo(Council)
Consul.belongsTo(Member)
Consul.hasMany(ConsulStake, { as: 'voters' })
Consul.hasMany(ProposalVote, { as: 'votes' })
ConsulStake.belongsTo(Consul)
ConsulStake.belongsTo(Member)

Channel.belongsTo(Member, { as: 'owner' })

Category.hasMany(Thread)
Category.belongsTo(Member, { as: 'moderator' })

Thread.belongsTo(Category)
Thread.belongsTo(Member, { as: 'creator' })
Thread.belongsTo(Member, { as: 'moderator' })
Thread.hasMany(Post)

Post.belongsTo(Thread)
Post.belongsTo(Member, { as: 'author' })
Post.belongsTo(Member, { as: 'moderator' })

Proposal.belongsTo(Member, { as: 'author' })
Proposal.hasMany(ProposalVote, { as: 'votes' })
ProposalVote.belongsTo(Proposal)
ProposalVote.belongsTo(Consul)
ProposalVote.belongsTo(Member)

export {
  Account,
  Balance,
  Block,
  Channel,
  Council,
  Consul,
  ConsulStake,
  Era,
  Event,
  Member,
  Proposal,
  ProposalVote,
  Category,
  Thread,
  Post,
}
